@@ -650,6 +650,9 @@
 /*	Do not report the TLSRPT status for TLS protocol handshakes
 /*	that reuse a previously-negotiated TLS session (there is no new
 /*	information to report).
+/* .IP "\fBtls_required_enable (yes)\fR"
+/*	Enable support for the "TLS-Required: no" message header, defined
+/*	in RFC 8689.
 /* .IP "\fBrequiretls_enable (yes)\fR"
 /*	Enable support for the ESMTP verb "REQUIRETLS", defined in RFC
 /*	8689.
@@ -1706,16 +1709,16 @@ static void pre_init(char *unused_name, char **unused_argv)
     /*
      * REQUIRETLS enforcement uses a match list. No MATCH_FLAG_RETURN after
      * table lookup error, because fail-open is not a good option. We would
-     * have to defer all delivery requests anyway. Disable magic syntax for
-     * LMTP, because the syntax would interfere with UNIX-domain socket
+     * have to defer all delivery requests anyway. Disable /file/name magic
+     * for LMTP, because that would break the handling of UNIX-domain socket
      * pathnames.
      */
     if (var_requiretls_enable && *var_smtp_enforce_requiretls) {
-	int     flags = smtp_mode ? 0 : (MATCH_FLAG_NOFILE | MATCH_FLAG_NODICT);
+	int     flags = smtp_mode ? 0 : MATCH_FLAG_NOFILE;
 	const char *param_name = VAR_LMTP_SMTP(ENFORCE_REQUIRETLS);
 
 	smtp_enforce_requiretls =
-	    string_list_init(param_name,
+	    domain_list_init(param_name,
 			     match_parent_style(param_name) | flags,
 			     var_smtp_enforce_requiretls);
     }
